@@ -16,8 +16,6 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-
-
 #Reclustering: suggests EM or k-means
 
 #' ClusTree Data Stream Clusterer
@@ -28,16 +26,18 @@
 #' ClusTree uses a compact and self-adaptive index structure for maintaining
 #' stream summaries. Kranen et al (2009) suggest EM or k-means for reclustering.
 #'
+#' @family DSC_MOA
+#'
 #' @aliases DSC_ClusTree ClusTree clustree
 #' @param horizon Range of the (time) window.
 #' @param maxHeight The maximum height of the tree.
 #' @param lambda number used to override computed lambda (decay).
 #' @param k If specified, k-means with k clusters is used for reclustering.
-#' @return An object of class \code{DSC_ClusTree} (subclass of \code{DSC},
-#' \code{DSC_MOA}, \code{DSC_Micro}).
+#' @return An object of class `DSC_ClusTree` (subclass of [DSC],
+#' [DSC_MOA], [DSC_Micro]).
 #' @author Michael Hahsler and John Forrest
-#' @seealso \code{\link{DSC}}, \code{\link{DSC_Micro}}, \code{\link{DSC_MOA}}
-#' @references Philipp Kranen, Ira Assent, Corinna Baldauf, and Thomas Seidl.
+#' @references
+#' Philipp Kranen, Ira Assent, Corinna Baldauf, and Thomas Seidl.
 #' 2009. Self-Adaptive Anytime Stream Clustering. In Proceedings of the 2009
 #' Ninth IEEE International Conference on Data Mining (ICDM '09). IEEE Computer
 #' Society, Washington, DC, USA, 249-258. \doi{10.1109/ICDM.2009.47}
@@ -46,52 +46,46 @@
 #' (2010). MOA: Massive Online Analysis, a Framework for Stream Classification
 #' and Clustering. In Journal of Machine Learning Research (JMLR).
 #' @examples
+#' # data with 3 clusters
+#' set.seed(1000)
+#' stream <- DSD_Gaussians(k = 3, d = 2, noise = 0.05)
 #'
-#' # data with 3 clusters and 5% noise
-#' stream <- DSD_Gaussians(k=3, d=2, noise=0.05)
-#'
-#' # Use automatically the k-means reclusterer with k=3 to create macro clusters
-#' clustree <- DSC_ClusTree(maxHeight=3, k = 3)
+#' clustree <- DSC_ClusTree(maxHeight = 3)
 #' update(clustree, stream, 500)
 #' clustree
 #'
-#' # plot micro-clusters
-#' plot(clustree, stream, , type = "both")
+#' plot(clustree, stream)
 #'
-#' # create a two stage clustering using ClusTree and reachability reclustering
-#' CTxReach <- DSC_TwoStage(
-#'   micro=DSC_ClusTree(maxHeight=3),
-#'   macro=DSC_Reachability(epsilon = .15)
-#' )
-#' CTxReach
-#' update(CTxReach, stream, 1000)
-#' plot(CTxReach, stream, type = "both")
+#' #' Use automatically the k-means reclusterer with k = 3 to create macro clusters
+#' clustree <- DSC_ClusTree(maxHeight = 3, k = 3)
+#' update(clustree, stream, 500)
+#' clustree
 #'
-#' @export DSC_ClusTree
-DSC_ClusTree <- function(horizon = 1000, maxHeight = 8, lambda = NULL,
-  k = NULL) {
+#' plot(clustree, stream, type = "both")
+#' @export
+DSC_ClusTree <-
+  function(horizon = 1000,
+    maxHeight = 8,
+    lambda = NULL,
+    k = NULL) {
+    ### Java code does parameter checking
+    # ClusTree (anytime clustering) options:
+    # IntOption("horizon", 'h', "Range of the window.", 1000)
+    # IntOption("maxHeight", 'H', "The maximal height of the tree", 8)
+    paramList <- list(h = horizon,
+      H = maxHeight)
 
-  ### Java code does parameter checking
-  # ClusTree (anytime clustering) options:
-  # IntOption("horizon", 'h', "Range of the window.", 1000)
-  # IntOption("maxHeight", 'H', "The maximal height of the tree", 8)
-  paramList <- list(
-    h=horizon,
-    H=maxHeight
-  )
-
-  clus <- DSC_MOA_Clusterer("moa/clusterers/clustree/ClusTree", "ClusTree",
-    paramList)
-
-  # overwrite lambda
-  if(!is.null(lambda))
-  	.jfield(clus$javaObj, "negLambda") <- -1*lambda
-
-  # note that reachability and single-link hc are equivalent
-  if(!is.null(k)) clus <- DSC_TwoStage(clus, DSC_Kmeans(k = k, nstart = 5))
-
-  clus
-}
+    clus <-
+      DSC_MOA_Clusterer("moa/clusterers/clustree/ClusTree", "ClusTree",
+        paramList)
 
+    # overwrite lambda
+    if (!is.null(lambda))
+      .jfield(clus$javaObj, "negLambda") <- -1 * lambda
 
+    # note that reachability and single-link hc are equivalent
+    if (!is.null(k))
+      clus <- DSC_TwoStage(clus, DSC_Kmeans(k = k, nstart = 5))
 
+    clus
+  }
